@@ -771,8 +771,9 @@ def compute_plot_excel_kpis_meterics_metrics(data, title, local_root_directory='
 
             daily_df['month'] = daily_df.apply(rename_month, axis=1)
 
-            epochkpis_df = daily_df[['year', 'month', me_strat]].groupby(['year', 'month']).apply(go_comp_kpi)
-
+            epochkpis_series = daily_df[['year', 'month', me_strat]].groupby(['year', 'month']).apply(go_comp_kpi)
+            epochkpis_df = pd.DataFrame().from_records(epochkpis_series.values)
+            epochkpis_df.index = epochkpis_series.index
             if write_file:
                 writer = pd.ExcelWriter(local_root_directory + f'epoch_{me_strat_name}_{title}.xlsx',
                                         engine='xlsxwriter')
